# spooky_chess

Rust and Python library for the game of Chess.

# Rust

```fish
cargo add spooky_chess
```

# Python

```fish
uv add spooky-chess
```

## Develop

### Tests

- `fish run_tests.fish`
    - `fish run_python_tests.fish`
    - `fish run_rust_tests.fish`

### Lints

- `fish run_lints.fish`
